@@ -1,7 +1,7 @@
 /*
  * This file is part of uudeview, the simple and friendly multi-part multi-
- * file uudecoder  program  (c) 1994-2001 by Frank Pilhofer. The author may
- * be contacted at fp@fpx.de
+ * file uudecoder  program  (c)  1994 by Frank Pilhofer. The author may be
+ * contacted by his email address,          fp@informatik.uni-frankfurt.de
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
 
 /*
  * This file implements the externally visible functions, as declared
- * in uudeview.h, and some internal interfacing functions
+ * in uulib.h, and some internal interfacing functions
  */
 
 #ifdef HAVE_CONFIG_H
@@ -76,12 +76,12 @@
 #include <io.h>
 #endif
 
-#include <uudeview.h>
+#include <uulib.h>
 #include <uuint.h>
 #include <fptools.h>
 #include <uustring.h>
 
-char * uulib_id = "$Id: uulib.c,v 1.11 2002/10/13 13:08:44 root Exp $";
+char * uulib_id = "$Id: uulib.c,v 1.16 1996/11/03 12:49:07 fp Exp $";
 
 #ifdef SYSTEM_WINDLL
 BOOL _export WINAPI 
@@ -114,17 +114,15 @@ DllEntryPoint (HINSTANCE hInstance, DWORD seginfo,
  * Callback functions and their opaque arguments
  */
 
-void   (*uu_MsgCallback)     (void *, char *, int)         = NULL;
-int    (*uu_BusyCallback)    (void *, uuprogress *)        = NULL;
-int    (*uu_FileCallback)    (void *, char *, char *, int) = NULL;
-char * (*uu_FNameFilter)     (void *, char *)              = NULL;
-char * (*uu_FileNameCallback)(void *, char *, char *);
-;
+void   (*uu_MsgCallback)  (void *, char *, int)         = NULL;
+int    (*uu_BusyCallback) (void *, uuprogress *)        = NULL;
+int    (*uu_FileCallback) (void *, char *, char *, int) = NULL;
+char * (*uu_FNameFilter)  (void *, char *)              = NULL;
+
 void *uu_MsgCBArg  = NULL;
 void *uu_BusyCBArg = NULL;
 void *uu_FileCBArg = NULL;
 void *uu_FFCBArg   = NULL;
-void *uu_FNCBArg;
 
 /*
  * Global variables
@@ -143,9 +141,6 @@ int uu_ignmode = 0;		/* ignore the original file mode            */
 int uu_handletext = 0;		/* do we want text/plain messages           */
 int uu_usepreamble = 0;		/* do we want Mime preambles/epilogues      */
 int uu_tinyb64 = 0;		/* detect short B64 outside of MIME         */
-int uu_remove_input = 0;        /* remove input files after decoding        */
-int uu_more_mime = 0;           /* strictly adhere to MIME headers          */
-int uu_dotdot = 0;		/* dot-unescaping has not yet been done     */
 
 headercount hlcount = {
   3,			        /* restarting after a MIME body             */
@@ -229,29 +224,29 @@ typedef struct {
 } allomap;
 
 static allomap toallocate[] = {
-  { &uugen_fnbuffer,    4096 },  /* generic filename buffer */
+  { &uugen_fnbuffer,    1024 },  /* generic filename buffer */
   { &uugen_inbuffer,    1024 },  /* generic input data buffer */
   { &uucheck_lastname,   256 },	 /* from uucheck.c */
   { &uucheck_tempname,   256 },
   { &uuestr_itemp,       256 },  /* from uuencode.c:UUEncodeStream() */
-  { &uuestr_otemp,      1024 },
+  { &uuestr_otemp,       256 },
   { &uulib_msgstring,   1024 },  /* from uulib.c:UUMessage() */
-  { &uuncdl_fulline,    1200 },  /* from uunconc.c:UUDecodeLine() */
-  { &uuncdp_oline,      3600 },  /* from uunconc.c:UUDecodePart() */
+  { &uuncdl_fulline,     256 },  /* from uunconc.c:UUDecodeLine() */
+  { &uuncdp_oline,       512 },  /* from uunconc.c:UUDecodePart() */
   { &uunconc_UUxlat,     256 * sizeof (int) },  /* from uunconc.c:toplevel */
   { &uunconc_UUxlen,      64 * sizeof (int) },
   { &uunconc_B64xlat,    256 * sizeof (int) },
   { &uunconc_XXxlat,     256 * sizeof (int) },
   { &uunconc_BHxlat,     256 * sizeof (int) },
-  { &uunconc_save,    3*1200 },  /* from uunconc.c:decoding buffer */
+  { &uunconc_save,     3*256 },  /* from uunconc.c:decoding buffer */
   { &uuscan_shlline,    1024 },  /* from uuscan.c:ScanHeaderLine() */
-  { &uuscan_pvvalue,     300 },  /* from uuscan.c:ParseValue() */
-  { &uuscan_phtext,      300 },  /* from uuscan.c:ParseHeader() */
-  { &uuscan_sdline,      300 },  /* from uuscan.c:ScanData() */
-  { &uuscan_sdbhds1,     300 },
-  { &uuscan_sdbhds2,     300 },
-  { &uuscan_spline,      300 },  /* from uuscan.c:ScanPart() */
-  { &uuutil_bhwtmp,      300 },  /* from uuutil.c:UUbhwrite() */
+  { &uuscan_pvvalue,     256 },  /* from uuscan.c:ParseValue() */
+  { &uuscan_phtext,      256 },  /* from uuscan.c:ParseHeader() */
+  { &uuscan_sdline,      256 },  /* from uuscan.c:ScanData() */
+  { &uuscan_sdbhds1,     256 },
+  { &uuscan_sdbhds2,     256 },
+  { &uuscan_spline,      256 },  /* from uuscan.c:ScanPart() */
+  { &uuutil_bhwtmp,      256 },  /* from uuutil.c:UUbhwrite() */
   { NULL, 0 }
 };
 
@@ -395,7 +390,7 @@ UUInitialize (void)
        * areas (uulib_msgstring) in UUMessage()
        */
       for (aiter=toallocate; aiter->ptr; aiter++) {
-	_FP_free (*(aiter->ptr));
+	FP_free (*(aiter->ptr));
       }
       return UURET_NOMEM;
     }
@@ -421,7 +416,7 @@ UUGetOption (int option, int *ivalue, char *cvalue, int clength)
 
   switch (option) {
   case UUOPT_VERSION:
-    _FP_strncpy (cvalue, uulibversion, clength);
+    FP_strncpy (cvalue, uulibversion, clength);
     result = 0;
     break;
   case UUOPT_FAST:
@@ -461,7 +456,7 @@ UUGetOption (int option, int *ivalue, char *cvalue, int clength)
     result = uu_overwrite;
     break;
   case UUOPT_SAVEPATH:
-    _FP_strncpy (cvalue, uusavepath, clength);
+    FP_strncpy (cvalue, uusavepath, clength);
     result = 0;
     break;
   case UUOPT_PROGRESS:
@@ -489,21 +484,9 @@ UUGetOption (int option, int *ivalue, char *cvalue, int clength)
     result = uu_tinyb64;
     break;
   case UUOPT_ENCEXT:
-    _FP_strncpy (cvalue, uuencodeext, clength);
+    FP_strncpy (cvalue, uuencodeext, clength);
     result = 0;
     break;
-  case UUOPT_REMOVE:
-    if (ivalue) *ivalue = uu_remove_input;
-    result = uu_remove_input;
-    break;
-  case UUOPT_MOREMIME:
-    if (ivalue) *ivalue = uu_more_mime;
-    result = uu_more_mime;
-    break;
-  case UUOPT_DOTDOT:
-    if (ivalue) *ivalue = uu_dotdot;
-    result = uu_dotdot;
-    break;
   default:
     return -1;
   }
@@ -539,8 +522,8 @@ UUSetOption (int option, int ivalue, char *cvalue)
     uu_overwrite      = ivalue;
     break;
   case UUOPT_SAVEPATH:
-    _FP_free (uusavepath);
-    uusavepath = _FP_strdup (cvalue);
+    FP_free (uusavepath);
+    uusavepath = FP_strdup (cvalue);
     break;
   case UUOPT_IGNMODE:
     uu_ignmode = ivalue;
@@ -555,17 +538,8 @@ UUSetOption (int option, int ivalue, char *cvalue)
     uu_tinyb64 = ivalue;
     break;
   case UUOPT_ENCEXT:
-    _FP_free (uuencodeext);
-    uuencodeext = _FP_strdup (cvalue);
-    break;
-  case UUOPT_REMOVE:
-    uu_remove_input = ivalue;
-    break;
-  case UUOPT_MOREMIME:
-    uu_more_mime = ivalue;
-    break;
-  case UUOPT_DOTDOT:
-    uu_dotdot = ivalue;
+    FP_free (uuencodeext);
+    uuencodeext = FP_strdup (cvalue);
     break;
   default:
     return UURET_ILLVAL;
@@ -625,16 +599,6 @@ UUSetFNameFilter (void *opaque,
   return UURET_OK;
 }
 
-int UUEXPORT
-UUSetFileNameCallback (void *opaque,
-		       char * (*func) (void *, char *, char *))
-{
-  uu_FileNameCallback = func;
-  uu_FNCBArg          = opaque;
-
-  return UURET_OK;
-}
-
 /*
  * Return a pointer to the nth element of the GlobalFileList
  * zero-based, returns NULL if item is too large.
@@ -712,10 +676,10 @@ UULoadFile (char *filename, char *fileid, int delflag, int *partcount)
       UUMessage (uulib_id, __LINE__, UUMSG_WARNING,
 		 uustring (S_OUT_OF_MEMORY), sizeof (itbd));
     }
-    else if ((killem->fname = _FP_strdup (filename)) == NULL) {
+    else if ((killem->fname = FP_strdup (filename)) == NULL) {
       UUMessage (uulib_id, __LINE__, UUMSG_WARNING,
 		 uustring (S_OUT_OF_MEMORY), strlen(filename)+1);
-      _FP_free (killem);
+      FP_free (killem);
     }
     else {
       killem->NEXT = ftodel;
@@ -729,7 +693,7 @@ UULoadFile (char *filename, char *fileid, int delflag, int *partcount)
   progress.fsize    = (long) ((finfo.st_size>0)?finfo.st_size:-1);
   progress.percent  = 0;
   progress.foffset  = 0;
-  _FP_strncpy (progress.curfile,
+  FP_strncpy (progress.curfile,
 	       (strlen(filename)>255)?
 	       (filename+strlen(filename)-255):filename,
 	       256);
@@ -775,7 +739,6 @@ UULoadFile (char *filename, char *fileid, int delflag, int *partcount)
     }
 
     if ((loaded->uudet == QP_ENCODED || loaded->uudet == PT_ENCODED) &&
-	(loaded->filename == NULL || *(loaded->filename) == '\0') &&
 	!uu_handletext && (loaded->flags&FL_PARTIAL)==0) {
       /*
        * Don't want text
@@ -934,7 +897,7 @@ UUDecodeFile (uulist *thefile, char *destname)
   if (destname)
     strcpy (uugen_fnbuffer, destname);
   else {
-    sprintf (uugen_fnbuffer, "%.1024s%.3071s",
+    sprintf (uugen_fnbuffer, "%s%s",
 	     (uusavepath)?uusavepath:"",
 	     UUFNameFilter ((thefile->filename)?
 			    thefile->filename:"unknown.xxx"));
@@ -961,22 +924,8 @@ UUDecodeFile (uulist *thefile, char *destname)
     return UURET_IOERR;
   }
 
-  /* try rename() shortcut first */
-  if (!rename (thefile->binfile, uugen_fnbuffer))
-    {
-      mode_t mask = 0000; /* there is a slight window here anyway */
-#if HAVE_UMASK
-      mask = umask (0022); umask (mask);
-#endif
-      fclose (source);
-#if HAVE_CHMOD
-      chmod (uugen_fnbuffer, thefile->mode & ~mask);
-#endif
-      goto skip_copy;
-    }
-
   progress.action   = 0;
-  _FP_strncpy (progress.curfile,
+  FP_strncpy (progress.curfile,
 	       (strlen(uugen_fnbuffer)>255)?
 	       (uugen_fnbuffer+strlen(uugen_fnbuffer)-255):uugen_fnbuffer,
 	       256);
@@ -1056,9 +1005,7 @@ UUDecodeFile (uulist *thefile, char *destname)
 	       thefile->binfile,
 	       strerror (uu_errno = errno));
   }
-
-skip_copy:
-  _FP_free (thefile->binfile);
+  FP_free (thefile->binfile);
   thefile->binfile = NULL;
   thefile->state  &= ~UUFILE_TMPFILE;
   thefile->state  |=  UUFILE_DECODED;
@@ -1107,7 +1054,7 @@ UUInfoFile (uulist *thefile, void *opaque,
 		 strerror (uu_errno=errno));
       return UURET_IOERR;
     }
-    _FP_strncpy (uugen_fnbuffer, thefile->thisfile->data->sfname, 1024);
+    FP_strncpy (uugen_fnbuffer, thefile->thisfile->data->sfname, 1024);
   }
 
   /*
@@ -1119,7 +1066,7 @@ UUInfoFile (uulist *thefile, void *opaque,
 
   while (!feof (inpfile) && 
 	 (uu_fast_scanning || ftell(inpfile) < maxpos)) {
-    if (_FP_fgets (uugen_inbuffer, 511, inpfile) == NULL)
+    if (FP_fgets (uugen_inbuffer, 511, inpfile) == NULL)
       break;
     uugen_inbuffer[511] = '\0';
 
@@ -1135,9 +1082,6 @@ UUInfoFile (uulist *thefile, void *opaque,
     else if ((thefile->uudet == UU_ENCODED || thefile->uudet == XX_ENCODED) &&
 	     strncmp (uugen_inbuffer, "begin ", 6) == 0)
       break;
-    else if (thefile->uudet == YENC_ENCODED &&
-	     strncmp (uugen_inbuffer, "=ybegin ", 8) == 0)
-      break;
 
     if ((*func) (opaque, uugen_inbuffer))
       break;
@@ -1173,14 +1117,14 @@ UURenameFile (uulist *thefile, char *newname)
 
   oldname = thefile->filename;
 
-  if ((thefile->filename = _FP_strdup (newname)) == NULL) {
+  if ((thefile->filename = FP_strdup (newname)) == NULL) {
     UUMessage (uulib_id, __LINE__, UUMSG_ERROR,
 	       uustring (S_NOT_RENAME),
 	       oldname, newname);
     thefile->filename = oldname;
     return UURET_NOMEM;
   }
-  _FP_free (oldname);
+  FP_free (oldname);
   return UURET_OK;
 }
 
@@ -1197,7 +1141,7 @@ UURemoveTemp (uulist *thefile)
 		 thefile->binfile,
 		 strerror (uu_errno = errno));
     }
-    _FP_free (thefile->binfile);
+    FP_free (thefile->binfile);
     thefile->binfile = NULL;
     thefile->state  &= ~UUFILE_TMPFILE;
   }
@@ -1208,58 +1152,30 @@ int UUEXPORT
 UUCleanUp (void)
 {
   itbd *iter=ftodel, *ptr;
-  uulist *liter;
-  uufile *fiter;
   allomap *aiter;
 
-  /*
-   * delete temporary input files (such as the copy of stdin)
-   */
+  UUkilllist (UUGlobalFileList);
+  UUGlobalFileList = NULL;
 
+  /*
+   * delete input files
+   */
   while (iter) {
     if (unlink (iter->fname)) {
       UUMessage (uulib_id, __LINE__, UUMSG_WARNING,
 		 uustring (S_TMP_NOT_REMOVED),
 		 iter->fname, strerror (uu_errno = errno));
     }
-    _FP_free (iter->fname);
+    FP_free (iter->fname);
     ptr  = iter;
     iter = iter->NEXT;
-    _FP_free (ptr);
+    FP_free (ptr);
   }
-
   ftodel = NULL;
 
-  /*
-   * Delete input files after successful decoding
-   */
-
-  if (uu_remove_input) {
-    liter = UUGlobalFileList;
-    while (liter) {
-      if (liter->state & UUFILE_DECODED) {
-	fiter = liter->thisfile;
-	while (fiter) {
-	  if (fiter->data && fiter->data->sfname) {
-	    /*
-	     * Error code ignored. We might want to delete a file multiple
-	     * times
-	     */
-	    unlink (fiter->data->sfname);
-	  }
-	  fiter = fiter->NEXT;
-	}
-      }
-      liter = liter->NEXT;
-    }
-  }
-
-  UUkilllist (UUGlobalFileList);
-  UUGlobalFileList = NULL;
-
-  _FP_free (uusavepath);
-  _FP_free (uuencodeext);
-  _FP_free (sstate.source);
+  FP_free (uusavepath);
+  FP_free (uuencodeext);
+  FP_free (sstate.source);
 
   uusavepath  = NULL;
   uuencodeext = NULL;
@@ -1272,7 +1188,7 @@ UUCleanUp (void)
   while (mssdepth) {
     mssdepth--;
     UUkillheaders (&(multistack[mssdepth].envelope));
-    _FP_free (multistack[mssdepth].source);
+    FP_free (multistack[mssdepth].source);
   }
 
   /*
@@ -1280,7 +1196,7 @@ UUCleanUp (void)
    */
 
   for (aiter=toallocate; aiter->ptr; aiter++) {
-    _FP_free (*(aiter->ptr));
+    FP_free (*(aiter->ptr));
     *(aiter->ptr) = NULL;
   }
 
